==> customer-link-project-api-0.0.25-20221202.090336-3-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app87225/vo/NearShopVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app87225.vo;

import java.util.List;

/**
 * @author zht
 * @description
 * @createTime 2022年11月30日
 */
public class NearShopVO {

    /**
     * 门店编码  0:单品1:多品
     */
    private Integer storeType;
    /**
     * 是否有线上门店
     */
    private Integer hasOnlineSale;
    /**
     * 纬度
     */
    private Long latitude;
    /**
     * 经度
     */
    private Long longitude;
    /**
     * 线上门店地址
     */
    private String xcxOnlineStoreUrl;
    /**
     * 企微
     */
    private String workWxUrl;
    /**
     * 线上门店地址
     */
    private String appOnlineStoreUrl;
    /**
     * 门店距离，单位米
     */
    private Integer storeDistance;
    /**
     * 门店编码
     */
    private String storeNo;
    /**
     * 门店地址
     */
    private String storeAddress;
    /**
     * 门店名
     */
    private String storeName;
    /**
     * 门店电话
     */
    private String tel;
    /**
     *
     */
    private String id;
    /**
     * 主营品牌
     */
    private List<String> mainSaleBrandNos;

    public Integer getStoreType() {
        return storeType;
    }

    public void setStoreType(Integer storeType) {
        this.storeType = storeType;
    }

    public Integer getHasOnlineSale() {
        return hasOnlineSale;
    }

    public void setHasOnlineSale(Integer hasOnlineSale) {
        this.hasOnlineSale = hasOnlineSale;
    }

    public Long getLatitude() {
        return latitude;
    }

    public void setLatitude(Long latitude) {
        this.latitude = latitude;
    }

    public Long getLongitude() {
        return longitude;
    }

    public void setLongitude(Long longitude) {
        this.longitude = longitude;
    }

    public String getXcxOnlineStoreUrl() {
        return xcxOnlineStoreUrl;
    }

    public void setXcxOnlineStoreUrl(String xcxOnlineStoreUrl) {
        this.xcxOnlineStoreUrl = xcxOnlineStoreUrl;
    }

    public String getWorkWxUrl() {
        return workWxUrl;
    }

    public void setWorkWxUrl(String workWxUrl) {
        this.workWxUrl = workWxUrl;
    }

    public String getAppOnlineStoreUrl() {
        return appOnlineStoreUrl;
    }

    public void setAppOnlineStoreUrl(String appOnlineStoreUrl) {
        this.appOnlineStoreUrl = appOnlineStoreUrl;
    }

    public Integer getStoreDistance() {
        return storeDistance;
    }

    public void setStoreDistance(Integer storeDistance) {
        this.storeDistance = storeDistance;
    }

    public String getStoreNo() {
        return storeNo;
    }

    public void setStoreNo(String storeNo) {
        this.storeNo = storeNo;
    }

    public String getStoreAddress() {
        return storeAddress;
    }

    public void setStoreAddress(String storeAddress) {
        this.storeAddress = storeAddress;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public List<String> getMainSaleBrandNos() {
        return mainSaleBrandNos;
    }

    public void setMainSaleBrandNos(List<String> mainSaleBrandNos) {
        this.mainSaleBrandNos = mainSaleBrandNos;
    }
}

==> customer-link-project-api-0.0.25-20221213.014402-8-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app87225/vo/NearShopVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app87225.vo;

import java.util.List;

/**
 * @author zht
 * @description
 * @createTime 2022年11月30日
 */
public class NearShopVO {

    /**
     * 门店编码  0:单品1:多品
     */
    private Integer storeType;
    /**
     * 是否有线上门店
     */
    private Integer hasOnlineSale;
    /**
     * 纬度
     */
    private Long latitude;
    /**
     * 经度
     */
    private Long longitude;
    /**
     * 线上门店地址
     */
    private String xcxOnlineStoreUrl;
    /**
     * 企微
     */
    private String workWxUrl;
    /**
     * 线上门店地址
     */
    private String appOnlineStoreUrl;
    /**
     * 门店距离，单位米
     */
    private Integer distance;
    /**
     * 门店编码
     */
    private String storeNo;
    /**
     * 门店地址
     */
    private String storeAddress;
    /**
     * 门店名
     */
    private String storeName;
    /**
     * 门店电话
     */
    private String tel;
    /**
     *
     */
    private String id;
    /**
     * 主营品牌
     */
    private List<String> mainSaleBrandNos;

    public Integer getStoreType() {
        return storeType;
    }

    public void setStoreType(Integer storeType) {
        this.storeType = storeType;
    }

    public Integer getHasOnlineSale() {
        return hasOnlineSale;
    }

    public void setHasOnlineSale(Integer hasOnlineSale) {
        this.hasOnlineSale = hasOnlineSale;
    }

    public Long getLatitude() {
        return latitude;
    }

    public void setLatitude(Long latitude) {
        this.latitude = latitude;
    }

    public Long getLongitude() {
        return longitude;
    }

    public void setLongitude(Long longitude) {
        this.longitude = longitude;
    }

    public String getXcxOnlineStoreUrl() {
        return xcxOnlineStoreUrl;
    }

    public void setXcxOnlineStoreUrl(String xcxOnlineStoreUrl) {
        this.xcxOnlineStoreUrl = xcxOnlineStoreUrl;
    }

    public String getWorkWxUrl() {
        return workWxUrl;
    }

    public void setWorkWxUrl(String workWxUrl) {
        this.workWxUrl = workWxUrl;
    }

    public String getAppOnlineStoreUrl() {
        return appOnlineStoreUrl;
    }

    public void setAppOnlineStoreUrl(String appOnlineStoreUrl) {
        this.appOnlineStoreUrl = appOnlineStoreUrl;
    }

    public Integer getDistance() {
        return distance;
    }

    public void setDistance(Integer storeDistance) {
        this.distance = storeDistance;
    }

    public String getStoreNo() {
        return storeNo;
    }

    public void setStoreNo(String storeNo) {
        this.storeNo = storeNo;
    }

    public String getStoreAddress() {
        return storeAddress;
    }

    public void setStoreAddress(String storeAddress) {
        this.storeAddress = storeAddress;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public List<String> getMainSaleBrandNos() {
        return mainSaleBrandNos;
    }

    public void setMainSaleBrandNos(List<String> mainSaleBrandNos) {
        this.mainSaleBrandNos = mainSaleBrandNos;
    }
}
